==> tdepim-trinity-14.0.7.tar.xz: tdepim-trinity-14.0.7/libkpimidentities/identitycombo.cpp <==
/*  -*- c++ -*-
    identitycombo.cpp

    This file is part of KMail, the KDE mail client.
    Copyright (c) 2002 Marc Mutz <mutz@kde.org>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the TQt library by Trolltech AS, Norway (or with modified versions
    of TQt that use the same license as TQt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    TQt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "identitycombo.h"
#include "identity.h"
#include "identitymanager.h"

#include <tdelocale.h>

#include <assert.h>

using namespace KPIM;

IdentityCombo::IdentityCombo( IdentityManager* manager, TQWidget * parent, const char * name )
  : TQComboBox( false, parent, name ), mIdentityManager( manager )
{
  reloadCombo();
  reloadUoidList();
  connect( this, TQT_SIGNAL(activated(int)), TQT_SLOT(slotEmitChanged(int)) );
  connect( manager, TQT_SIGNAL(changed()),
	   TQT_SLOT(slotIdentityManagerChanged()) );
}

TQString IdentityCombo::currentIdentityName() const {
  return mIdentityManager->identities()[ currentItem() ];
}

uint IdentityCombo::currentIdentity() const {
  return mUoidList[ currentItem() ];
}

void IdentityCombo::setCurrentIdentity( const Identity & identity ) {
  setCurrentIdentity( identity.uoid() );
}

void IdentityCombo::setCurrentIdentity( const TQString & name ) {
  int idx = mIdentityManager->identities().findIndex( name );
  if ( idx < 0 ) return;
  if ( idx == currentItem() ) return;

  blockSignals( true ); // just in case TQt gets fixed to emit activated() here
  setCurrentItem( idx );
  blockSignals( false );

  slotEmitChanged( idx );
}

void IdentityCombo::setCurrentIdentity( uint uoid ) {
  int idx = mUoidList.findIndex( uoid );
  if ( idx < 0 ) return;
  if ( idx == currentItem() ) return;

  blockSignals( true ); // just in case TQt gets fixed to emit activated() here
  setCurrentItem( idx );
  blockSignals( false );

  slotEmitChanged( idx );
}

void IdentityCombo::reloadCombo() {
  TQStringList identities = mIdentityManager->identities();
  // the IM should prevent this from happening:
  assert( !identities.isEmpty() );
  identities.first() = i18n("%1 (Default)").arg( identities.first() );
  clear();
  insertStringList( identities );
}

void IdentityCombo::reloadUoidList() {
  mUoidList.clear();
  IdentityManager::ConstIterator it;
  for ( it = mIdentityManager->begin() ; it != mIdentityManager->end() ; ++it )
    mUoidList << (*it).uoid();
}

void IdentityCombo::slotIdentityManagerChanged() {
  uint oldIdentity = mUoidList[ currentItem() ];

  reloadUoidList();
  int idx = mUoidList.findIndex( oldIdentity );

  blockSignals( true );
  reloadCombo();
  setCurrentItem( idx < 0 ? 0 : idx );
  blockSignals( false );

  if ( idx < 0 )
    // apparently our oldIdentity got deleted:
    slotEmitChanged( currentItem() );
}

void IdentityCombo::slotEmitChanged( int idx ) {
  emit identityChanged( mIdentityManager->identities()[idx] );
  emit identityChanged( mUoidList[idx] );
}

#include "identitycombo.moc"

==> tdepim-trinity_14.1.5.orig.tar.xz: tdepim-trinity-14.1.5/libkpimidentities/identitycombo.cpp <==
/*
    identitycombo.cpp

    This file is part of KMail, the KDE mail client.
    Copyright (c) 2002 Marc Mutz <mutz@kde.org>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the TQt library by Trolltech AS, Norway (or with modified versions
    of TQt that use the same license as TQt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    TQt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "identitycombo.h"
#include "identity.h"
#include "identitymanager.h"

#include <tdelocale.h>

#include <assert.h>

using namespace KPIM;

IdentityCombo::IdentityCombo( IdentityManager* manager, TQWidget * parent, const char * name )
  : TQComboBox( false, parent, name ), mIdentityManager( manager )
{
  reloadCombo();
  reloadUoidList();
  connect( this, TQ_SIGNAL(activated(int)), TQ_SLOT(slotEmitChanged(int)) );
  connect( manager, TQ_SIGNAL(changed()),
	   TQ_SLOT(slotIdentityManagerChanged()) );
}

TQString IdentityCombo::currentIdentityName() const {
  return mIdentityManager->identities()[ currentItem() ];
}

uint IdentityCombo::currentIdentity() const {
  return mUoidList[ currentItem() ];
}

void IdentityCombo::setCurrentIdentity( const Identity & identity ) {
  setCurrentIdentity( identity.uoid() );
}

void IdentityCombo::setCurrentIdentity( const TQString & name ) {
  int idx = mIdentityManager->identities().findIndex( name );
  if ( idx < 0 ) return;
  if ( idx == currentItem() ) return;

  blockSignals( true ); // just in case TQt gets fixed to emit activated() here
  setCurrentItem( idx );
  blockSignals( false );

  slotEmitChanged( idx );
}

void IdentityCombo::setCurrentIdentity( uint uoid ) {
  int idx = mUoidList.findIndex( uoid );
  if ( idx < 0 ) return;
  if ( idx == currentItem() ) return;

  blockSignals( true ); // just in case TQt gets fixed to emit activated() here
  setCurrentItem( idx );
  blockSignals( false );

  slotEmitChanged( idx );
}

void IdentityCombo::reloadCombo() {
  TQStringList identities = mIdentityManager->identities();
  // the IM should prevent this from happening:
  assert( !identities.isEmpty() );
  identities.first() = i18n("%1 (Default)").arg( identities.first() );
  clear();
  insertStringList( identities );
}

void IdentityCombo::reloadUoidList() {
  mUoidList.clear();
  IdentityManager::ConstIterator it;
  for ( it = mIdentityManager->begin() ; it != mIdentityManager->end() ; ++it )
    mUoidList << (*it).uoid();
}

void IdentityCombo::slotIdentityManagerChanged() {
  uint oldIdentity = mUoidList[ currentItem() ];

  reloadUoidList();
  int idx = mUoidList.findIndex( oldIdentity );

  blockSignals( true );
  reloadCombo();
  setCurrentItem( idx < 0 ? 0 : idx );
  blockSignals( false );

  if ( idx < 0 )
    // apparently our oldIdentity got deleted:
    slotEmitChanged( currentItem() );
}

void IdentityCombo::slotEmitChanged( int idx ) {
  emit identityChanged( mIdentityManager->identities()[idx] );
  emit identityChanged( mUoidList[idx] );
}

#include "identitycombo.moc"
